This function uses the Open Topography SRTM Version 3 files.
get_opentopo(locations, src, prj, expand = NULL, ...)Either a data.frame of x (long) and y (lat), an
sp, an sf, or raster object as input.
A string defining the projection of the locations argument. The
string needs to be an acceptable SRS_string for
CRS-class for your version of PROJ. If a sf
object, a sp object or a raster object
is provided, the string will be taken from that. This
argument is required for a data.frame of locations.
A numeric value of a distance, in map units, used to expand the bounding box that is used to fetch the SRTM data.
Extra configuration parameters to be passed to httr::GET. Common
usage is to adjust timeout. This is done as
config=timeout(x) where x is a numeric value in
seconds. Multiple configuration functions may be passed as a
vector.