Learn R Programming

elevatr (version 0.3.1)

get_opentopo: Get a digital elevation model from the Open Topography SRTM Version 3

Description

This function uses the Open Topography SRTM Version 3 files.

Usage

get_opentopo(locations, src, prj, expand = NULL, ...)

Arguments

locations

Either a data.frame of x (long) and y (lat), an sp, an sf, or raster object as input.

prj

PROJ.4 string for input bbox

expand

A numeric value of a distance, in map units, used to expand the bounding box that is used to fetch the SRTM data.

...

Extra configuration parameters to be passed to httr::GET. Common usage is to adjust timeout. This is done as config=timeout(x) where x is a numeric value in seconds. Multiple configuration functions may be passed as a vector.